.. # ********** Please don't edit this file!
.. # ********** It has been generated automatically by dae_devops version 0.5.2.
.. # ********** For repository_name soakdb3

Naming conventions
=======================================================================

Here are the naming conventions used within the source code.

variables
    lowercase, underscores

constants
    uppercase, underscores

classes
    camel case

class methods
    lowercase, underscores

imports
    require fully qualified package name (import <package> does nothing)

    exception: top-level packages __init__.py will have __version__ defined in them

python packages
    lowercase, underscores

repository
    lowercase, hyphens


.. # dae_devops_fingerprint 1e0adc6d888883afb554f2a9ce26c63a
